# Generated by roxygen2: do not edit by hand

S3method(build_ui_for,default)
S3method(build_ui_for,ptr_layer)
S3method(build_ui_for,ptr_literal)
S3method(build_ui_for,ptr_missing)
S3method(build_ui_for,ptr_ph_data_consumer)
S3method(build_ui_for,ptr_ph_data_source)
S3method(build_ui_for,ptr_ph_value)
S3method(build_ui_for,ptr_user_expr)
S3method(classify_walk,default)
S3method(classify_walk,ptr_call)
S3method(classify_walk,ptr_layer)
S3method(classify_walk,ptr_ph_data_consumer)
S3method(classify_walk,ptr_ph_data_source)
S3method(classify_walk,ptr_pipeline)
S3method(classify_walk,ptr_root)
S3method(disable_walk,default)
S3method(disable_walk,ptr_call)
S3method(disable_walk,ptr_layer)
S3method(disable_walk,ptr_pipeline)
S3method(disable_walk,ptr_root)
S3method(print,ptr_shared_state)
S3method(prune_walk,default)
S3method(prune_walk,ptr_call)
S3method(prune_walk,ptr_closure)
S3method(prune_walk,ptr_layer)
S3method(prune_walk,ptr_literal)
S3method(prune_walk,ptr_missing)
S3method(prune_walk,ptr_ph_data_consumer)
S3method(prune_walk,ptr_ph_data_source)
S3method(prune_walk,ptr_ph_value)
S3method(prune_walk,ptr_pipeline)
S3method(prune_walk,ptr_root)
S3method(prune_walk,ptr_user_expr)
S3method(render_walk,default)
S3method(render_walk,ptr_call)
S3method(render_walk,ptr_closure)
S3method(render_walk,ptr_layer)
S3method(render_walk,ptr_literal)
S3method(render_walk,ptr_missing)
S3method(render_walk,ptr_ph_data_consumer)
S3method(render_walk,ptr_ph_data_source)
S3method(render_walk,ptr_ph_value)
S3method(render_walk,ptr_pipeline)
S3method(render_walk,ptr_root)
S3method(render_walk,ptr_user_expr)
S3method(stamp_current_pick_walk,default)
S3method(stamp_current_pick_walk,ptr_call)
S3method(stamp_current_pick_walk,ptr_closure)
S3method(stamp_current_pick_walk,ptr_layer)
S3method(stamp_current_pick_walk,ptr_ph_data_consumer)
S3method(stamp_current_pick_walk,ptr_ph_data_source)
S3method(stamp_current_pick_walk,ptr_ph_value)
S3method(stamp_current_pick_walk,ptr_pipeline)
S3method(stamp_current_pick_walk,ptr_root)
S3method(substitute_walk,default)
S3method(substitute_walk,ptr_call)
S3method(substitute_walk,ptr_closure)
S3method(substitute_walk,ptr_layer)
S3method(substitute_walk,ptr_literal)
S3method(substitute_walk,ptr_missing)
S3method(substitute_walk,ptr_ph_data_consumer)
S3method(substitute_walk,ptr_ph_data_source)
S3method(substitute_walk,ptr_ph_value)
S3method(substitute_walk,ptr_pipeline)
S3method(substitute_walk,ptr_root)
S3method(substitute_walk,ptr_user_expr)
S3method(walk_ptr_safety,default)
S3method(walk_ptr_safety,ptr_call)
S3method(walk_ptr_safety,ptr_layer)
S3method(walk_ptr_safety,ptr_literal)
S3method(walk_ptr_safety,ptr_missing)
S3method(walk_ptr_safety,ptr_ph_data_consumer)
S3method(walk_ptr_safety,ptr_ph_data_source)
S3method(walk_ptr_safety,ptr_ph_value)
S3method(walk_ptr_safety,ptr_pipeline)
S3method(walk_ptr_safety,ptr_root)
S3method(walk_ptr_safety,ptr_user_expr)
export(embellish_identity)
export(embellish_symbol_to_string)
export(ppExpr)
export(ppLayerOff)
export(ppNum)
export(ppText)
export(ppUpload)
export(ppVar)
export(ppVerbSwitch)
export(ptr_app)
export(ptr_arg_expression)
export(ptr_arg_numeric)
export(ptr_arg_string)
export(ptr_arg_symbol)
export(ptr_arg_symbol_or_string)
export(ptr_clear_constant_fold)
export(ptr_clear_placeholder)
export(ptr_constant_fold_keywords)
export(ptr_define_placeholder_consumer)
export(ptr_define_placeholder_source)
export(ptr_define_placeholder_value)
export(ptr_extract_code)
export(ptr_extract_error)
export(ptr_extract_plot)
export(ptr_gg_extra)
export(ptr_ggplotly)
export(ptr_id_table)
export(ptr_init_state)
export(ptr_llm_primer)
export(ptr_llm_register)
export(ptr_llm_topic)
export(ptr_llm_topics)
export(ptr_normalize_column_names)
export(ptr_options)
export(ptr_plotly_selection)
export(ptr_register_constant_fold)
export(ptr_resolve_ui_text)
export(ptr_server)
export(ptr_shared)
export(ptr_shared_panel)
export(ptr_shared_server)
export(ptr_signal_partial)
export(ptr_ui)
export(ptr_ui_assets)
export(ptr_ui_code)
export(ptr_ui_controls)
export(ptr_ui_error)
export(ptr_ui_header)
export(ptr_ui_inline_error)
export(ptr_ui_page)
export(ptr_ui_plot)
export(ptr_ui_shared_panel)
export(ptr_ui_text)
export(ptr_ui_toggle_code)
export(ptr_wrap_placeholder_addin)
import(ggplot2)
importFrom(rlang,"%||%")
