% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/paintr-llm.R
\name{ptr_llm_topics}
\alias{ptr_llm_topics}
\title{List available ggpaintr LLM topic names}
\usage{
ptr_llm_topics()
}
\value{
A character vector.
}
\description{
Returns the character vector of topic names accepted by
\code{\link[=ptr_llm_topic]{ptr_llm_topic()}}. Matches the files in \verb{inst/llm/topics/} (stripped
of the \code{.md} extension), sorted alphabetically.
}
\examples{
ptr_llm_topics()
}
\seealso{
\code{\link[=ptr_llm_topic]{ptr_llm_topic()}}, \code{\link[=ptr_llm_primer]{ptr_llm_primer()}}
}
